
from . import abstract, decorators, interface
from .checker import (
    Checker,
    CheckerSummary,
    Problems)
from .decorators import preload
from .interface import IProblems


__all__ = (
    "abstract",
    "Checker",
    "CheckerSummary",
    "decorators",
    "interface",
    "IProblems",
    "preload",
    "Problems")




from typing import List, Optional

import abstracts

from aio.run.checker import interface


@abstracts.implementer(interface.IProblems)
class AProblems(metaclass=abstracts.Abstraction):

    def __init__(
            self,
            errors: Optional[List[str]] = None,
            warnings: Optional[List[str]] = None) -> None:
        self._errors = errors
        self._warnings = warnings

    @property
    def errors(self) -> List[str]:
        return self._errors or []

    @property
    def warnings(self) -> List[str]:
        return self._warnings or []




from typing import List

import abstracts


class IProblems(metaclass=abstracts.Interface):

    @property  # type:ignore
    @abstracts.interfacemethod
    def errors(self) -> List[str]:
        raise NotImplementedError

    @property  # type:ignore
    @abstracts.interfacemethod
    def warnings(self) -> List[str]:
        raise NotImplementedError
